@@ -29,7 +29,7 @@
 #![doc(
     html_logo_url = "https://raw.githubusercontent.com/RustCrypto/meta/master/logo.svg",
     html_favicon_url = "https://raw.githubusercontent.com/RustCrypto/meta/master/logo.svg",
-    html_root_url = "https://docs.rs/pkcs1/0.1.0"
+    html_root_url = "https://docs.rs/pkcs1/0.2.2"
 )]
 #![forbid(unsafe_code, clippy::unwrap_used)]
 #![warn(missing_docs, rust_2018_idioms, unused_qualifications)]
@@ -42,13 +42,13 @@ extern crate std;
 mod error;
 mod private_key;
 mod public_key;
+mod traits;
 mod version;
 
 #[cfg(feature = "alloc")]
 mod document;
 
-#[cfg(feature = "alloc")]
-pub use crate::document::{private_key::RsaPrivateKeyDocument, public_key::RsaPublicKeyDocument};
+pub use der::{self, asn1::UIntBytes};
 
 #[cfg(feature = "pem")]
 use pem_rfc7468 as pem;
@@ -57,5 +57,12 @@ pub use self::{
     error::{Error, Result},
     private_key::RsaPrivateKey,
     public_key::RsaPublicKey,
+    traits::{FromRsaPrivateKey, FromRsaPublicKey},
     version::Version,
 };
+
+#[cfg(feature = "alloc")]
+pub use crate::{
+    document::{private_key::RsaPrivateKeyDocument, public_key::RsaPublicKeyDocument},
+    traits::{ToRsaPrivateKey, ToRsaPublicKey},
+};
